@@ -71,17 +71,18 @@ DisplayBase::FreeText()
 // x and y are the center left coordinates of the string
 void 
 DisplayBase::DrawText(const int x, int y, const string &text, 
-                      const unsigned char color[3])
+                      const unsigned char color[3], const double opacity)
 {
-    textRenderer_->DrawText(x, y, text, color);
+    textRenderer_->DrawText(x, y, text, color, opacity);
 }
 
 // x and y are the center left coordinates of the string
 void 
 DisplayBase::DrawOutlinedText(const int x, int y, const string &text, 
-                              const unsigned char color[3])
+                              const unsigned char color[3], 
+                              const double opacity)
 {
-    textRenderer_->DrawOutlinedText(x, y, text, color);
+    textRenderer_->DrawOutlinedText(x, y, text, color, opacity);
 }
 
 void
@@ -100,7 +101,7 @@ DisplayBase::drawLabelLine(int &currentX, int &currentY, const string &text)
         currentX = (options->LabelX() + width_ - 2 - textWidth);
     }
 
-    DrawOutlinedText(currentX, currentY, text, options->Color());
+    DrawOutlinedText(currentX, currentY, text, options->Color(), 1.0);
     currentY += textRenderer_->FontHeight();
 }
 
@@ -452,13 +453,48 @@ DisplayBase::setPixel(const int x, const int y, const unsigned char pixel[3])
     setPixel(x, y, pixel, 1.0);
 }
 
+void
+DisplayBase::setPixel(const int x, const int y, const unsigned char p[3],
+                      const double opacity[3])
+{
+    if (x < 0 || x >= width_ || y < 0 || y >= height_) return;
+
+    int ipos = y*width_ + x;
+    unsigned char *background = rgb_data + 3*ipos;
+    unsigned char pixel[3];
+    memcpy(pixel, p, 3);
+
+    double meanOpacity = 0;
+    for (int i = 0; i < 3; i++) meanOpacity += opacity[i];
+    meanOpacity /= 3; 
+
+    if (meanOpacity < 1)
+    {
+        for (int i = 0; i < 3; i++)
+            pixel[i] = (unsigned char) (opacity[i] * p[i] 
+                                        + (1 - opacity[i]) * background[i]);
+        if (alpha != NULL)
+        {
+            int thisAlpha = (int) (meanOpacity * 255 + alpha[ipos]);
+            alpha[ipos] = (unsigned char) (thisAlpha > 255 ? 255 : thisAlpha);
+        }
+    }
+    else
+    {
+        if (alpha != NULL) alpha[ipos] = 255;
+    }
+
+    memcpy(background, pixel, 3);
+}
+
 void
 DisplayBase::setPixel(const int x, const int y, const unsigned char p[3],
                       const double opacity)
 {
     if (x < 0 || x >= width_ || y < 0 || y >= height_) return;
 
-    unsigned char *background = rgb_data + 3*(y*width_ + x);
+    int ipos = y*width_ + x;
+    unsigned char *background = rgb_data + 3*ipos;
     unsigned char pixel[3];
     memcpy(pixel, p, 3);
     if (opacity < 1)
@@ -466,8 +502,11 @@ DisplayBase::setPixel(const int x, const int y, const unsigned char p[3],
         for (int i = 0; i < 3; i++)
             pixel[i] = (unsigned char) (opacity * p[i] 
                                         + (1 - opacity) * background[i]);
-        if (alpha != NULL) 
-            alpha[y*width_ + x] = (unsigned char) (opacity * 255);
+        if (alpha != NULL)
+        {
+            int thisAlpha = (int) (opacity * 255 + alpha[ipos]);
+            alpha[ipos] = (unsigned char) (thisAlpha > 255 ? 255 : thisAlpha);
+        }
     }
     else
     {
