@@ -30,6 +30,8 @@ public:
     void setPixel(const int x, const int y, const unsigned char pixel[3]);
     void setPixel(const int x, const int y, const unsigned char pixel[3],
                   const double opacity);
+    void setPixel(const int x, const int y, const unsigned char pixel[3],
+                  const double opacity[3]);
     void getPixel(const int x, const int y, unsigned char pixel[3]) const;
 
     virtual void renderImage(PlanetProperties *planetProperties[]) = 0;
@@ -42,9 +44,9 @@ public:
 
     void setText(const std::string &text);
     void DrawText(const int x, int y, const std::string &text, 
-                  const unsigned char color[3]);
+                  const unsigned char color[3], const double opacity);
     void DrawOutlinedText(const int x, int y, const std::string &text, 
-                          const unsigned char color[3]);
+                          const unsigned char color[3], const double opacity);
     void FreeText();
     void getTextBox(int &textWidth, int &textHeight);
 
