@@ -1,6 +1,7 @@
 #include <cmath>
 #include <cstdio>
 #include <cctype>
+#include <cstring>
 #include <sstream>
 #include <string>
 using namespace std;
@@ -890,6 +891,12 @@ Planet::getPosition(double &X, double &Y, double &Z) const
     Z = Z_;
 }
 
+double
+Planet::Illumination(const double oX, const double oY, const double oZ)
+{
+    return(50 * (ndot(X_, Y_, Z_, X_ - oX, Y_ - oY, Z_ - oZ) + 1));
+}
+
 void
 Planet::CreateRotationMatrix()
 {
@@ -979,7 +986,7 @@ Planet::XYZToPlanetocentric(const double X, const double Y, const double Z,
     else
         lat = 0;
 
-    if (cos(lat) > 1e-5)
+    if (cos(lat) > 0)
         lon = atan2(sy, sx);
     else
         lon = 0;
@@ -1123,18 +1130,6 @@ Planet::getOrbitalNorth(double &X, double &Y, double &Z) const
     Z = north[2]/mag;
 }
 
-void
-Planet::getGalacticNorth(double &X, double &Y, double &Z) const
-{
-    // B1950.0 coordinates of the galactic north pole
-    const double GN_LAT = 27.4 * deg_to_rad;
-    const double GN_LON = 192.25 * deg_to_rad;
-
-    X = cos(GN_LAT) * cos(GN_LON);
-    Y = cos(GN_LAT) * sin(GN_LON);
-    Z = sin(GN_LAT);              
-}
-
 void
 Planet::getBodyNorth(double &X, double &Y, double &Z) const
 {
