@@ -1,5 +1,6 @@
 #include <clocale>
 #include <cstdio>
+#include <cstring>
 #include <fstream>
 #include <sstream>
 #include <string>
@@ -97,15 +98,15 @@ readConfig(const char *line, PlanetProperties *planetProperties[])
         break;
         case BUMP_MAP:
         {
-	    // This is one that doesn't belong in [default]
-	    if (currentProperties == defaultProperties)
-	    {
-		ostringstream errStr;
-		errStr << "bump_map specified in [default] section.  "
-		       << "You probably want to put it in a specific "
-		       << "planet's section (like [earth]).\n";
-		xpWarn(errStr.str(), __FILE__, __LINE__);
-	    }
+            // This is one that doesn't belong in [default]
+            if (currentProperties == defaultProperties)
+            {
+                ostringstream errStr;
+                errStr << "bump_map specified in [default] section.  "
+                       << "You probably want to put it in a specific "
+                       << "planet's section (like [earth]).\n";
+                xpWarn(errStr.str(), __FILE__, __LINE__);
+            }
             string bumpMap(returnString);
             if (bumpMap.find('.') == string::npos)
                 bumpMap += defaultMapExt;
@@ -121,6 +122,17 @@ readConfig(const char *line, PlanetProperties *planetProperties[])
             checkLocale(LC_NUMERIC, "");
         }
         break;
+        case BUMP_SHADE:
+        {
+            int s;
+            sscanf(returnString, "%d", &s);
+            if (s < 0) 
+                s = 0;
+            else if (s > 100) 
+                s = 100;
+            currentProperties->BumpShade(s/100.);
+        }
+        break;
         case CLOUD_GAMMA:
         {
             checkLocale(LC_NUMERIC, "C");
@@ -132,15 +144,15 @@ readConfig(const char *line, PlanetProperties *planetProperties[])
         break;
         case CLOUD_MAP:
         {
-	    // This is one that doesn't belong in [default]
-	    if (currentProperties == defaultProperties)
-	    {
-		ostringstream errStr;
-		errStr << "cloud_map specified in [default] section.  "
-		       << "You probably want to put it in a specific "
-		       << "planet's section (like [earth]).\n";
-		xpWarn(errStr.str(), __FILE__, __LINE__);
-	    }
+            // This is one that doesn't belong in [default]
+            if (currentProperties == defaultProperties)
+            {
+                ostringstream errStr;
+                errStr << "cloud_map specified in [default] section.  "
+                       << "You probably want to put it in a specific "
+                       << "planet's section (like [earth]).\n";
+                xpWarn(errStr.str(), __FILE__, __LINE__);
+            }
             string cloudMap(returnString);
             if (cloudMap.find('.') == string::npos)
                 cloudMap += defaultMapExt;
@@ -179,15 +191,15 @@ readConfig(const char *line, PlanetProperties *planetProperties[])
         break;
         case DAY_MAP:
         case IMAGE:
-	    // This is one that doesn't belong in [default]
-	    if (currentProperties == defaultProperties)
-	    {
-		ostringstream errStr;
-		errStr << "image or map specified in [default] section.  "
-		       << "You probably want to put it in a specific "
-		       << "planet's section (like [earth]).\n";
-		xpWarn(errStr.str(), __FILE__, __LINE__);
-	    }
+            // This is one that doesn't belong in [default]
+            if (currentProperties == defaultProperties)
+            {
+                ostringstream errStr;
+                errStr << "image or map specified in [default] section.  "
+                       << "You probably want to put it in a specific "
+                       << "planet's section (like [earth]).\n";
+                xpWarn(errStr.str(), __FILE__, __LINE__);
+            }
             currentProperties->DayMap(returnString);
             break;
         case DELIMITER:
@@ -254,15 +266,15 @@ readConfig(const char *line, PlanetProperties *planetProperties[])
         break;
         case MAP_BOUNDS:
         {
-	    // This is one that doesn't belong in [default]
-	    if (currentProperties == defaultProperties)
-	    {
-		ostringstream errStr;
-		errStr << "map_bounds specified in [default] section.  "
-		       << "You probably want to put it in a specific "
-		       << "planet's section (like [earth]).\n";
-		xpWarn(errStr.str(), __FILE__, __LINE__);
-	    }
+            // This is one that doesn't belong in [default]
+            if (currentProperties == defaultProperties)
+            {
+                ostringstream errStr;
+                errStr << "map_bounds specified in [default] section.  "
+                       << "You probably want to put it in a specific "
+                       << "planet's section (like [earth]).\n";
+                xpWarn(errStr.str(), __FILE__, __LINE__);
+            }
             checkLocale(LC_NUMERIC, "C");
             double uly, ulx, lry, lrx;
             int numRead = sscanf(returnString, "%lf,%lf,%lf,%lf", 
@@ -343,27 +355,27 @@ readConfig(const char *line, PlanetProperties *planetProperties[])
         }
         break;
         case NAME:
-	    // This is one that doesn't belong in [default]
-	    if (currentProperties == defaultProperties)
-	    {
-		ostringstream errStr;
-		errStr << "name specified in [default] section.  "
-		       << "You probably want to put it in a specific "
-		       << "planet's section (like [earth]).\n";
-		xpWarn(errStr.str(), __FILE__, __LINE__);
-	    }
+            // This is one that doesn't belong in [default]
+            if (currentProperties == defaultProperties)
+            {
+                ostringstream errStr;
+                errStr << "name specified in [default] section.  "
+                       << "You probably want to put it in a specific "
+                       << "planet's section (like [earth]).\n";
+                xpWarn(errStr.str(), __FILE__, __LINE__);
+            }
             currentProperties->Name(returnString);
             break;
         case NIGHT_MAP:
-	    // This is one that doesn't belong in [default]
-	    if (currentProperties == defaultProperties)
-	    {
-		ostringstream errStr;
-		errStr << "night_map specified in [default] section.  "
-		       << "You probably want to put it in a specific "
-		       << "planet's section (like [earth]).\n";
-		xpWarn(errStr.str(), __FILE__, __LINE__);
-	    }
+            // This is one that doesn't belong in [default]
+            if (currentProperties == defaultProperties)
+            {
+                ostringstream errStr;
+                errStr << "night_map specified in [default] section.  "
+                       << "You probably want to put it in a specific "
+                       << "planet's section (like [earth]).\n";
+                xpWarn(errStr.str(), __FILE__, __LINE__);
+            }
             currentProperties->NightMap(returnString);
             break;
         case ORBIT:
@@ -409,6 +421,36 @@ readConfig(const char *line, PlanetProperties *planetProperties[])
             currentProperties->RandomTarget(returnString[0] == 't' 
                                             || returnString[0] == 'T');
             break;
+        case RAYLEIGH_EMISSION_WEIGHT:
+        {
+            checkLocale(LC_NUMERIC, "C");
+            double scale;
+            sscanf(returnString, "%lf", &scale);
+            currentProperties->RayleighEmissionWeight(scale);
+            checkLocale(LC_NUMERIC, "");
+        }
+        break;
+        case RAYLEIGH_FILE:
+            currentProperties->RayleighFile(returnString);
+            break;
+        case RAYLEIGH_LIMB_SCALE:
+        {
+            checkLocale(LC_NUMERIC, "C");
+            double scale;
+            sscanf(returnString, "%lf", &scale);
+            currentProperties->RayleighLimbScale(scale);
+            checkLocale(LC_NUMERIC, "");
+        }
+        break;
+        case RAYLEIGH_SCALE:
+        {
+            checkLocale(LC_NUMERIC, "C");
+            double scale;
+            sscanf(returnString, "%lf", &scale);
+            currentProperties->RayleighScale(scale);
+            checkLocale(LC_NUMERIC, "");
+        }
+        break;
         case SATELLITE_FILE:
             currentProperties->AddSatelliteFile(returnString);
             break;
@@ -441,6 +483,21 @@ readConfig(const char *line, PlanetProperties *planetProperties[])
             }
         }
         break;
+        case THICKNESS:
+        {
+            int thickness;
+            sscanf(returnString, "%d", &thickness);
+            if (thickness > 0)
+            {
+                currentProperties->ArcThickness(thickness);
+            }
+            else
+            {
+                xpWarn("thickness must be positive.\n", 
+                       __FILE__, __LINE__);
+            }
+        }
+        break;
         case TWILIGHT:
         {
             int value;
